@@ -1,7 +1,9 @@
-from peek_plugin_docdb_generic_menu._private.server.controller.MainController import \
-    MainController
-from peek_plugin_docdb_generic_menu.server.DocDbGenericMenuApiABC import \
-    DocDbGenericMenuApiABC
+from peek_plugin_docdb_generic_menu._private.server.controller.MainController import (
+    MainController,
+)
+from peek_plugin_docdb_generic_menu.server.DocDbGenericMenuApiABC import (
+    DocDbGenericMenuApiABC,
+)
 
 
 class DocDbGenericMenuApi(DocDbGenericMenuApiABC):
@@ -22,6 +24,5 @@ class DocDbGenericMenuApi(DocDbGenericMenuApiABC):
     #
     #     return DoSomethingTuplemethingTuple(result="SUCCESS : " + somethingsDescription)
 
-
     def shutdown(self):
         pass
